# Mango

Mango is a Genomics visualization library that uses Spark [Apache
Spark](https://spark.apache.org) and ADAM [ADAM](http://adam.readthedocs.io) to visualize
genomic data. Mango builds upon pileup.js [pileup.js](https://github.com/hammerlab/pileup.js) 
to support specific genomic visualizations.

## Documentation

Mango's documentation is hosted at [readthedocs](http://bdg-mango.readthedocs.io).

